#! /bin/bash
# @(#)create_geneclust_jar 1.0.0b11
#
# Script wrapper for creating the GeneClust front end JAR file
#

typeset script_name_without_path="${0##*/}"
typeset script_name="${script_name_without_path%.*}"

typeset package=GeneClust
typeset jar_file=$package.jar
typeset manifest_file=$package.mf

typeset java_base_dir=${1:-$HOME/geneclust/java}
typeset java_class_dir=$java_base_dir/classes
typeset java_jar_dir=$java_base_dir/jars
typeset java_manifest_dir=$java_base_dir/manifest
typeset java_doc_dir=$java_base_dir/doc
typeset java_src_dir=$java_base_dir/src


#
# Tactical
#
function compile_source
{
    #typeset sourcepath="-sourcepath $java_src_dir"
    #typeset classpath="-classpath ."
    #typeset outputdir="-d ."

    #typeset javac_flags="$sourcepath $classpath $outputdir"
    #typeset source_file="source_files.list"

    typeset  sourcepath="-sourcepath $java_src_dir"
    typeset  classpath="-classpath ."
    typeset  outputdir="-d ."

    typeset  javac_flags="$sourcepath $classpath $outputdir"
    typeset  source_file="source_files.list"

    trap 'rm "$source_file"' ERR
    cd $java_class_dir
    find $java_src_dir -name "*.java" -follow > $source_file
    javac $javac_flags @$source_file || exit 1
    rm $source_file
    trap - ERR
}

function create_documentation
{
    typeset sourcepath="-sourcepath $java_src_dir"
    typeset classpath="-classpath ."
    typeset outputdir="-d $java_doc_dir"

    typeset javadoc_flags="$sourcepath $classpath $outputdir"
    typeset jvm_version=$( ../bin/get_jvm_version |
                              awk '{ print substr($1, 1, 3) }' )
    typeset options_file=../bin/scripts/javadoc_options-$jvm_version
    typeset app_pkg=org.mdanderson.biostat.geneclust
    typeset util_pkg=org.mdanderson.biostat.util
    typeset misc_pkg=edu.stanford.ejalbert

    cd $java_class_dir
    javadoc $javadoc_flags $app_pkg $util_pkg $misc_pkg @$options_file
}

function copy_additional_files_to_class_hier
{
    typeset property_file
    typeset property_files
    typeset image_file
    typeset image_files

    cd $java_src_dir

    property_files=$( find . -name "*.properties" -follow )
    for property_file in $property_files
    do
        cp $property_file $java_class_dir/$property_file
    done

    image_files=$( find . \( -name "*.jpg" -o \
                             -name "*.gif" \) -follow )
    for image_file in $image_files
    do
        if [ ! -w $java_class_dir/$image_file ]
        then
            cp $image_file $java_class_dir/$image_file
        else
            echo $script_name": Cannot create <"$image_file">"
        fi
    done
}

function create_jar_file
{
    typeset jar_contents

    cd $java_class_dir
    jar_contents=$( ls -1 )
    jar cmf $java_manifest_dir/$manifest_file \
            $java_jar_dir/$jar_file \
            $jar_contents && rm -rf $jar_contents
#            $jar_contents
}


#
# Strategic
#
trap 'exit 2' 1 2 3 10 11 15
if [ ! -d $java_base_dir ] ;
then
    echo $script_name": base directory <"$java_base_dir"> doesn't exist"
    exit 1
fi

compile_source
copy_additional_files_to_class_hier
create_jar_file
create_documentation
exit 0

