/*=================== FILE ABSTRACT ==========================================
 *
 * Synopsis::         Source for about panel interface
 *
 * File Name::        %M%
 * Version::          %I%
 * Type::             source
 * Date Completed::   %G%
 *
 * Environment::
 *     Language::     Java
 *     Computer::     Compaq/Alpha
 *     OS::           DigitalUNIX
 *     OSVersion::    4.0
 *
 * Module Information::
 *     Owner::        MDACC
 *     Department::   Biostatistics
 *     Researcher::   N/A
 *     Application::  <generic>
 *
 *============================================================================*/

/*
 * @(#)AboutPanel.java    1.0 2002/03/06
 *
 * Copyright (c) 2002 M.D. Anderson Cancer Center
 * 1515 Holcombe, Houston, TX, 77030, U.S.A.
 * All rights reserved.
 */

package org.mdanderson.biostat.util;

import java.util.Date;


/**
 * AboutPanel - Interface for panel settings.
 *
 * @version 1.0 2002/03/06
 * @author <a href="mailto:roebuck@mdanderson.org">P. Roebuck</a>
 */
public interface AboutPanel
{
    /**
     * Sets the application name and version to be displayed
     *
     * @param appName     string specifying application name to be displayed
     * @param appVersion  string specifying application version to be displayed
     */
    public void setAppVersionLine(String appName, String appVersion);

    /**
     * Sets the banner to be displayed
     *
     * @param banner  string specifying banner text to be displayed
     */
    public void setBannerLine(String banner);

    /**
     * Sets the copyright to be displayed
     *
     * @param copyright  string specifying banner text to be displayed
     */
    public void setCopyrightLine(String copyright);

    /**
     * Sets the legal text to be displayed
     *
     * @param legalities  string specifying legal text to be displayed
     */
    public void setLegalitiesLine(String legalities);

    /**
     * Sets the release date to be displayed
     *
     * @param date  <code>Date</code> specifying release date to be displayed
     */
    public void setReleaseDateLine(Date date);

    /**
     * Sets the release date to be displayed
     *
     * @param date  string specifying release date to be displayed
     */
    public void setReleaseDateLine(String date);

    /**
     * Shows or hides the copyright information depending on the
     * value of parameter
     *
     * @param visible  if true, shows copyright information; otherwise, hides it
     */
    public void setCopyrightVisible(boolean visible);

    /**
     * Shows or hides the legal information depending on the
     * value of parameter
     *
     * @param visible  if true, shows legal information; otherwise, hides it
     */
    public void setLegalitiesVisible(boolean visible);
}

