/*=================== FILE ABSTRACT ==========================================
 *
 * Synopsis::         Source for abstract state monitor class
 *
 * File Name::        %M%
 * Version::          %I%
 * Type::             source
 * Date Completed::   %G%
 *
 * Environment::
 *     Language::     Java
 *     Computer::     Compaq/Alpha
 *     OS::           DigitalUNIX
 *     OSVersion::    4.0
 *
 * Module Information::
 *     Owner::        MDACC
 *     Department::   Biostatistics
 *     Researcher::   N/A
 *     Application::  <generic>
 *
 *============================================================================*/

/*
 * @(#)AbstractStateMonitor.java    1.0 2002/03/17
 *
 * Copyright (c) 2002 M.D. Anderson Cancer Center
 * 1515 Holcombe, Houston, TX, 77030, U.S.A.
 * All rights reserved.
 */

package org.mdanderson.biostat.util;

import java.awt.Component;
import java.util.ArrayList;
import java.util.HashMap;
import java.util.Iterator;
import java.util.List;
import java.util.Map;


/**
 * AbstractStateMonitor - Responsible for enabling or disabling GUI components
 *                        whenever application state changes.
 *
 * @version 1.0 2002/03/17
 * @author <a href="mailto:roebuck@mdanderson.org">P. Roebuck</a>
 */
abstract public class AbstractStateMonitor
{
    // =========================================================================
    // CONSTRUCTOR
    // =========================================================================

    /**
     * Class constructor
     */
    public AbstractStateMonitor()
    {
        states = new ArrayList();
        active = new HashMap();
        components = new HashMap();
    }

    // =========================================================================
    // PUBLIC INTERFACE
    // =========================================================================

    /**
     * Returns the data that was checked
     *
     * @return  data that was checked
     */
    public void activate(Component component, Object state)
    {
        List list = (List) active.get(state);
        if (list == null)
            list = new ArrayList();

        if (list.contains(component) == false)
            list.add(component);

        active.put(state, list);
    }

    /**
     * Adds a state to the list of monitored states and updates
     * :TODO:  , if it doesn't already exist
     *
     * @param state  object representing state information
     */
    public void addState(Object state)
    {
        if (states.contains(state) == false)
        {
            states.add(state);
            update(state, 1);
        }
    }

    /**
     * Removes a state from the list of monitored states,
     * :TODO: if it doesn't already exist
     *
     * @param state  object representing state information
     */
    public void removeState(Object state)
    {
        if (states.contains(state) == true)
        {
            states.remove(state);
            update(state, -1);
        }
    }

    // =========================================================================
    // PACKAGE INTERFACE
    // =========================================================================

    /**
     * :TODO: Add better documentation
     *
     * @param state  object representing state information
     * @param delta  integer value which increments or decrements the count.
     */
    void update(Object state, int delta)
    {
        List list = (List)active.get(state);
        Iterator iter = list.iterator();

        while (iter.hasNext())
        {
            int newCount = delta;
            Component component = (Component)iter.next();
            Integer count = (Integer) components.get(component);
            if (count != null)
                newCount += count.intValue();
            if (newCount == 0)
                component.setEnabled(false);
            else if (newCount == 1)
                component.setEnabled(true);
            components.put(component, new Integer(newCount));
        }
    }

    // =========================================================================
    // OBJECT ATTRIBUTES
    // =========================================================================

    /** Currently active states */
    protected List states;

    /** Maps states to components */
    protected Map active;

    /** Maps components to activity count */
    protected Map components;
}

