/*=================== FILE ABSTRACT ==========================================
 *
 * Synopsis::         Source for MDACC logo imageIcon subclass
 *
 * File Name::        %M%
 * Version::          %I%
 * Type::             source
 * Date Completed::   %G%
 *
 * Environment::
 *     Language::     Java
 *     Computer::     Compaq/Alpha
 *     OS::           DigitalUNIX
 *     OSVersion::    4.0
 *
 * Module Information::
 *     Owner::        MDACC
 *     Department::   Biostatistics
 *     Researcher::   N/A
 *     Application::  <generic>
 *
 *============================================================================*/

/*
 * @(#)MdaccIcon.java    1.0 2002/01/15
 *
 * Copyright (c) 2002 M.D. Anderson Cancer Center
 * 1515 Holcombe, Houston, TX, 77030, U.S.A.
 * All rights reserved.
 */

package org.mdanderson.biostat.util;

import java.net.URL;
import java.util.MissingResourceException;
import java.util.ResourceBundle;
import javax.swing.ImageIcon;


/**
 * MdaccIcon - Create M&#x2E;D&#x2E; Anderson Cancer Center logo icons.
 *
 * @version 1.0 2002/01/15
 * @author <a href="mailto:roebuck@mdanderson.org">P. Roebuck</a>
 */
public class MdaccIcon extends ImageIcon
    implements MdaccIconKeys
{
    // =========================================================================
    // CONSTRUCTORS
    // =========================================================================

    /**
     * Class constructor
     */
    public MdaccIcon()
    {
        this(logoUrl, logoDescription);
    }

    /**
     * Class constructor specifying url
     *
     * @param url  url of logo image
     */
    public MdaccIcon(URL url)
    {
        this(url, logoDescription);
    }

    /**
     * Class constructor specifying accessible description
     *
     * @param description  string specifying accessible description
     */
    public MdaccIcon(String description)
    {
        this(logoUrl, description);
    }

    /**
     * Class constructor specifying url and accessible description
     *
     * @param url          url of logo image 
     * @param description  string specifying accessible description
     */
    public MdaccIcon(URL url, String description)
    {
        super(url, description);
    }

    // =========================================================================
    // CLASS INTERFACE
    // =========================================================================

    /**
     * Fetches messages from resource bundle.
     *
     * @param propertyKey  string containing property key for format string
     * @return             string containing message
     */
    static String getBundleString(String propertyKey)
    {
        String value = null;

        try
        {
            value = bundle.getString(propertyKey);
        }
        catch (MissingResourceException mre)
        {
            System.err.println(mre);
        }

        if (value == null)
            value = "Could not find resource: " + propertyKey + "  ";

        return value;
    }

    /**
     * Finds a resource with a given name. This method returns null if no
     * resource with this name is found. The rules for searching resources
     * associated with a given class are implemented by the defining class
     * loader of the class.
     *
     * @param resourceName  string specifying name of the desired resource
     * @return              url of requested resource
     * @see Class#getResource
     */
    static URL getResource(String resourceName)
    {
        return MdaccIcon.class.getResource(resourceName);
    }

    // =========================================================================
    // CLASS ATTRIBUTES
    // =========================================================================

    private static final ResourceBundle bundle;
    private static String logoDescription;
    private static URL logoUrl;

    static
    {
        final String propertyFile = MdaccIcon.class.getName();
        bundle = ResourceBundle.getBundle(propertyFile);

        final String logoFileName = "mdacc_logo_xs.gif";
        logoUrl = getResource(logoFileName);

        logoDescription = getBundleString(LOGO_DESCRIPTION);
    }
}

