/*=================== FILE ABSTRACT ==========================================
 *
 * Synopsis::         Source for numeric key filtering class
 *
 * File Name::        %M%
 * Version::          %I%
 * Type::             source
 * Date Completed::   %G%
 *
 * Environment::
 *     Language::     Java
 *     Computer::     Compaq/Alpha
 *     OS::           DigitalUNIX
 *     OSVersion::    4.0
 *
 * Module Information::
 *     Owner::        MDACC
 *     Department::   Biostatistics
 *     Researcher::   N/A
 *     Application::  <generic>
 *
 *============================================================================*/

/*
 * @(#)NumericFilter.java    1.0 2000/12/26
 *
 * Copyright (c) 2000 M.D. Anderson Cancer Center
 * 1515 Holcombe, Houston, TX, 77030, U.S.A.
 * All rights reserved.
 */

package org.mdanderson.biostat.util;

import java.awt.Component;
import java.awt.event.KeyEvent;


/**
 * NumericFilter - Implements numeric keyboard filtering.
 *
 * @version 1.0 2000/12/26
 * @author <a href="mailto:roebuck@mdanderson.org">P. Roebuck</a>
 */
public class NumericFilter extends Filter
{
    // =========================================================================
    // CONSTRUCTORS
    // =========================================================================

    /**
     * Class constructor specifying component
     *
     * @param component  component which would receive the keystrokes
     */
    public NumericFilter(Component component)
    {
        super(component);
    }

    // =========================================================================
    // PUBLIC INTERFACE
    // =========================================================================

    /**
     * Determines if the key is valid in this context. This implementation
     * allows digits, negative sign, decimal point. The backspace and delete
     * keys cannot be consumed and are allowed here to prevent
     * <code>Filter</code> from beeping when they are typed. Note that this
     * does not prevent an invalid format of acceptable characters.
     *
     * @param event  low-level event generated by a component when a key is
     *               pressed, released, or typed
     * @return       true if key is valid for this filter; otherwise, false
     * @see Filter
     */
    public boolean isKeyValid(KeyEvent event)
    {
        final char decimalPoint = '.';
        final char negativeSign = '-';
        char c = event.getKeyChar();

        return (Character.isDigit(c) ||
                (c == negativeSign) ||
                (c == decimalPoint) ||
                (c == KeyEvent.VK_BACK_SPACE) ||
                (c == KeyEvent.VK_DELETE));
    }
}

