/*=================== FILE ABSTRACT ==========================================
 *
 * Synopsis::         Source for status event class
 *
 * File Name::        %M%
 * Version::          %I%
 * Type::             source
 * Date Completed::   %G%
 *
 * Environment::
 *     Language::     Java
 *     Computer::     Compaq/Alpha
 *     OS::           DigitalUNIX
 *     OSVersion::    4.0
 *
 * Module Information::
 *     Owner::        MDACC
 *     Department::   Biostatistics
 *     Researcher::   N/A
 *     Application::  <generic>
 *
 *============================================================================*/

/*
 * @(#)StatusEvent.java    1.0 2000/12/27
 *
 * Copyright (c) 2000 M.D. Anderson Cancer Center
 * 1515 Holcombe, Houston, TX, 77030, U.S.A.
 * All rights reserved.
 */

package org.mdanderson.biostat.util;

import java.util.EventObject;


/**
 * StatusEvent - Event to notify listener of status change.
 *
 * @version 1.0 2000/12/27
 * @author <a href="mailto:roebuck@mdanderson.org">P. Roebuck</a>
 */
public class StatusEvent extends EventObject
{
    // =========================================================================
    // CONSTRUCTORS
    // =========================================================================

    /**
     * Class constructor specifying source, value, and status
     *
     * @param source  component whose value was checked
     * @param value   data that was checked
     * @param status  true if data is valid; otherwise, false
     */
    public StatusEvent(Object source, Object value, boolean status)
    {
        super(source);
        this.value = value;
        this.status = status;
    }

    // =========================================================================
    // PUBLIC INTERFACE
    // =========================================================================

    /**
     * Returns the data that was checked
     *
     * @return  data that was checked
     */
    public Object getValue()
    {
        return value;
    }

    /**
     * Returns the status of the data that was checked
     *
     * @return  true if data is valid; otherwise, false
     */
    public boolean getStatus()
    {
        return status;
    }

    // =========================================================================
    // OBJECT ATTRIBUTES
    // =========================================================================

    private Object value;
    private boolean status;
}

